import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * An iGroup is a collection of host initiators (IQNs) that are allowed access to a LUN. When LUNs are associated with iGroups, administrators gain control over which hosts can connect to and access each LUN, enabling secure and organized access management for applications and workloads consuming block storage. Once activated, you need a preview key to consume this resource. Please reach out to Ng-fsx-cloudformation@netapp.com to get the key. To use this resource, you must first create the Link module.
 *
 * @schema CfnIGroupProps
 */
export interface CfnIGroupProps {
    /**
     * The password source for the FSx admin user.
     *
     * @schema CfnIGroupProps#FsxAdminPasswordSource
     */
    readonly fsxAdminPasswordSource: PasswordSource;
    /**
     * The file system ID of the Amazon FSx for NetApp ONTAP file system in which the resource is created.
     *
     * @schema CfnIGroupProps#FileSystemId
     */
    readonly fileSystemId: string;
    /**
     * The ARN of the AWS Lambda function that will be invoked to manage the resource.
     *
     * @schema CfnIGroupProps#LinkArn
     */
    readonly linkArn: string;
    /**
     * The name of the initiator group.
     *
     * @schema CfnIGroupProps#Name
     */
    readonly name?: string;
    /**
     * The initiators that are attached to the initiator group.
     *
     * @schema CfnIGroupProps#Initiators
     */
    readonly initiators?: Initiator[];
    /**
     * The host operating system of the initiator group. All initiators in the group should be hosts of the same operating system.
     *
     * @schema CfnIGroupProps#OsType
     */
    readonly osType?: CfnIGroupPropsOsType;
    /**
     * The SVM information associated with the initiator group.
     *
     * @schema CfnIGroupProps#SVM
     */
    readonly svm?: Svm;
}
/**
 * Converts an object of type 'CfnIGroupProps' to JSON representation.
 */
export declare function toJson_CfnIGroupProps(obj: CfnIGroupProps | undefined): Record<string, any> | undefined;
/**
 * @schema PasswordSource
 */
export interface PasswordSource {
    /**
     * A reference to the source of the password, typically an AWS Secrets Manager secret.
     *
     * @schema PasswordSource#Secret
     */
    readonly secret: SecretSource;
}
/**
 * Converts an object of type 'PasswordSource' to JSON representation.
 */
export declare function toJson_PasswordSource(obj: PasswordSource | undefined): Record<string, any> | undefined;
/**
 * @schema Initiator
 */
export interface Initiator {
    /**
     * The FC WWPN, iSCSI IQN, or iSCSI EUI that identifies the host initiator.
     *
     * @schema Initiator#Name
     */
    readonly name: string;
}
/**
 * Converts an object of type 'Initiator' to JSON representation.
 */
export declare function toJson_Initiator(obj: Initiator | undefined): Record<string, any> | undefined;
/**
 * The host operating system of the initiator group. All initiators in the group should be hosts of the same operating system.
 *
 * @schema CfnIGroupPropsOsType
 */
export declare enum CfnIGroupPropsOsType {
    /** aix */
    AIX = "aix",
    /** hpux */
    HPUX = "hpux",
    /** hyper_v */
    HYPER_UNDERSCORE_V = "hyper_v",
    /** linux */
    LINUX = "linux",
    /** netware */
    NETWARE = "netware",
    /** openvms */
    OPENVMS = "openvms",
    /** solaris */
    SOLARIS = "solaris",
    /** solaris_efi */
    SOLARIS_UNDERSCORE_EFI = "solaris_efi",
    /** vmware */
    VMWARE = "vmware",
    /** windows */
    WINDOWS = "windows",
    /** windows_2008 */
    WINDOWS_UNDERSCORE_2008 = "windows_2008",
    /** windows_gpt */
    WINDOWS_UNDERSCORE_GPT = "windows_gpt",
    /** xen */
    XEN = "xen"
}
/**
 * @schema SVM
 */
export interface Svm {
    /**
     * The name of the SVM.
     *
     * @schema SVM#Name
     */
    readonly name?: string;
    /**
     * The UUID of the SVM.
     *
     * @schema SVM#UUID
     */
    readonly uuid?: string;
}
/**
 * Converts an object of type 'Svm' to JSON representation.
 */
export declare function toJson_Svm(obj: Svm | undefined): Record<string, any> | undefined;
/**
 * @schema SecretSource
 */
export interface SecretSource {
    /**
     * The ARN of the secret stored in AWS Secrets Manager.
     *
     * @schema SecretSource#SecretArn
     */
    readonly secretArn: string;
    /**
     * Reference for the SecretKey. The actual password is stored in AWS Secret Manager.
     *
     * @schema SecretSource#SecretKey
     */
    readonly secretKey: string;
}
/**
 * Converts an object of type 'SecretSource' to JSON representation.
 */
export declare function toJson_SecretSource(obj: SecretSource | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `NetApp::FSxN::IGroup`
 *
 * @cloudformationResource NetApp::FSxN::IGroup
 * @stability external
 * @link https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
 */
export declare class CfnIGroup extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "NetApp::FSxN::IGroup";
    /**
     * Resource props.
     */
    readonly props: CfnIGroupProps;
    /**
     * Attribute `NetApp::FSxN::IGroup.UUID`
     * @link https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
     */
    readonly attrUuid: string;
    /**
     * Create a new `NetApp::FSxN::IGroup`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnIGroupProps);
}
